<?php

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

require_once INTENSE_PLUGIN_FOLDER . '/inc/tools/tools.php';

class Intense {
	function __construct() {
		add_action( 'plugins_loaded', array( __CLASS__, 'init' ), 10 );
		add_action( 'init', array( __CLASS__, 'update' ), 20 );
		register_activation_hook( INTENSE_PLUGIN_FILE, array( __CLASS__, 'activation' ) );
		register_activation_hook( INTENSE_PLUGIN_FILE, array( __CLASS__, 'deactivation' ) );
		add_action( 'after_setup_theme', array( __CLASS__, 'after_setup_theme' ), 200 );
		add_action( 'admin_menu', array( __CLASS__, 'adjust_the_wp_menu' ), 999 );
	}

	/**
	 * Plugin initialization
	 */
	public static function init() {
		global $intense_post_types;
		global $intense_shortcodes;

		add_filter( 'redux/_url', array(  __CLASS__, 'redux_url' ), 0 );

		require_once INTENSE_PLUGIN_FOLDER . '/inc/Intense-photosource.php';
		require_once INTENSE_PLUGIN_FOLDER . '/inc/plugins/IVersionWP-Client.php';
		require_once INTENSE_PLUGIN_FOLDER . '/inc/options/options.php';
		require_once INTENSE_PLUGIN_FOLDER . '/inc/assets.php';
		require_once INTENSE_PLUGIN_FOLDER . '/inc/metaboxes.php';
		require_once INTENSE_PLUGIN_FOLDER . '/inc/custom-post-types.php';
		require_once INTENSE_PLUGIN_FOLDER . '/inc/shortcodes.php';
		require_once INTENSE_PLUGIN_FOLDER . '/inc/widgets.php';

		Intense_Shortcodes::load_shortcodes();
		Intense_Post_Types::load_custom_post_types();
		Intense_Widgets::load_widgets();

		if ( is_multisite() ) {
			require_once INTENSE_PLUGIN_FOLDER . '/inc/options/multisite.php';
			new Intense_Multisite_Options();
		}

		new Intense_Options();
		new Intense_Assets();
		new Intense_Metaboxes();
		$intense_post_types = new Intense_Post_Types();
		$intense_shortcodes = new Intense_Shortcodes();
		new Intense_Widgets();
		Intense::add_image_sizes();

		load_plugin_textdomain( 'intense', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );

		add_filter( 'load_textdomain_mofile', array( __CLASS__, 'replace_default_language_files' ), 10, 2 );
		add_filter( 'mime_types', array( __CLASS__, 'add_mime_types' ) );		

		do_action( 'intense/init' );
	}

	/**
	 * Plugin update
	 */
	public static function update() {
		global $intense_visions_options;
		global $intense_visions_multisite_options;

		$ivwp = new IVersionWP_Client( INTENSE_ACTIVATION_SERVER, INTENSE_PRODUCT_KEY, 'intense/intense.php', INTENSE_PLUGIN_VERSION );
		$auto_update =  ( !empty( $intense_visions_options['intense_auto_update'] ) && $intense_visions_options['intense_auto_update'] ) ||
			( !empty( $intense_visions_multisite_options['intense_auto_update'] ) && $intense_visions_multisite_options['intense_auto_update'] );

		if ( !empty( $intense_visions_options['intense_envato_username'] ) || !empty( $intense_visions_multisite_options['intense_envato_username'] ) ) {
			$envato_username = !is_multisite() ? $intense_visions_options['intense_envato_username'] : $intense_visions_multisite_options['intense_envato_username'];
			$api_key = !is_multisite() ? $intense_visions_options['intense_api_key'] : $intense_visions_multisite_options['intense_api_key'];

			if ( $auto_update ) {
				$ivwp->autoupdate( $envato_username, $api_key );
			}
		}
		
		if ( current_user_can( 'install_plugins' ) || current_user_can( 'activate_plugins' ) ) {
			if ( !current_theme_supports( 'intense-embedded' ) ) {			
				if ( !is_multisite() || is_super_admin() ) {
					$activation_path = !is_multisite() ? 'intense_visions_options' : 'intense_visions_multisite_options';
					$ivwp->setup_activation_reminder( sprintf(
							__( 'Hello. Please <a href="%s">activate Intense</a> to receive automatic updates.', 'intense' ),
							wp_nonce_url( admin_url( 'options-general.php?page=' . $activation_path . '&tab=Product_License' ) )
						) );
				}
			} else if ( current_theme_supports( 'intense-embedded' ) ) {			
				$GLOBALS['IntensePluginInlineStyle']['intense-embedded'] = "
					#License_section_group_li, .updated.iversionwp.intense { 
						display: none; 
					}
				";			
			}
		}

		if ( !empty( $intense_visions_options['intense_show_admin_bar'] ) ) {			
			Intense::intense_hide_admin_bar();
		}	

		$version = get_option( 'intense_version' );

		if ( $version != INTENSE_PLUGIN_VERSION ) {			
			require_once INTENSE_PLUGIN_FOLDER . '/inc/migrations/migrations.php';
			$migrations = new Intense_Migrations();
			$migrations->migrate( $version, INTENSE_PLUGIN_VERSION );

			update_option( 'intense_version', INTENSE_PLUGIN_VERSION );
			flush_rewrite_rules(); //reset the permalinks
			do_action( 'intense/update' );
		}
	}	

	/**
	 * Plugin activation
	 */
	public static function activation() {
		update_option( 'intense_version', INTENSE_PLUGIN_VERSION );
		flush_rewrite_rules(); //reset the permalinks
		do_action( 'intense/activation' );
	}

	/**
	 * Plugin deactivation
	 */
	public static function deactivation() {
		do_action( 'intense/deactivation' );
	}

	public static function after_setup_theme() {
		require_once INTENSE_PLUGIN_FOLDER . '/inc/plugins/tgmpa.php';
		// $shortcodeReflection = new ReflectionClass("TGM_Plugin_Activation");
		//       echo dirname( $shortcodeReflection->getFilename() );
	}

	public static function adjust_the_wp_menu() {
		if ( current_theme_supports( 'intense-embedded' ) ) {
			remove_submenu_page( 'options-general.php', 'intense_visions_multisite_options' );			
		}
	}

	/**
	 * Add image sizes
	 */
	public static function add_image_sizes() {
		global $intense_visions_options;

		if ( !empty( $intense_visions_options['intense_register_image_sizes'] ) && $intense_visions_options['intense_register_image_sizes'] ) {			
			if ( isset( $intense_visions_options['intense_custom_image_sizes'] ) && $intense_visions_options['intense_custom_image_sizes'] != '' ) {
				foreach ( $intense_visions_options['intense_custom_image_sizes'] as $key => $value ) {
					$sizes = explode( "|", $value );

					if ( !empty( $sizes[0] ) && !empty( $sizes[1] ) && !empty( $sizes[2] ) && !empty( $sizes[3] ) ) {
						add_image_size( $sizes[2], $sizes[0], $sizes[1], $sizes[3] );
					}
				}
			}

			$active_image_sizes = $intense_visions_options['intense_active_image_sizes'];

			$image_sizes = array(
				"square75" => array( "name" => "square75", "width" => 75, "height" => 75, "crop" => true ),
				"square150" => array( "name" => "square150", "width" => 150, "height" => 150, "crop" => true ),
				"square400" => array( "name" => "square400", "width" => 400, "height" => 400, "crop" => true ),
				"small240" => array( "name" => "small240", "width" => 240, "height" => 160, "crop" => true ),
				"small320" => array( "name" => "small320", "width" => 320, "height" => 213, "crop" => true ),
				"medium500" => array( "name" => "medium500", "width" => 500, "height" => 333, "crop" => true ),
				"medium640" => array( "name" => "medium640", "width" => 640, "height" => 427, "crop" => true ),
				"medium800" => array( "name" => "medium800", "width" => 800, "height" => 534, "crop" => true ),
				"large1024" => array( "name" => "large1024", "width" => 1024, "height" => 683, "crop" => true ),
				"large1600" => array( "name" => "large1600", "width" => 1600, "height" => 1067, "crop" => true ),
				"large2048" => array( "name" => "large2048", "width" => 2048, "height" => 1365, "crop" => true ),
				"portraitSmall" => array( "name" => "portraitSmall", "width" => 400, "height" => 500, "crop" => false ),
				"portraitMedium" => array( "name" => "portraitMedium", "width" => 800, "height" => 1000, "crop" => false ),
				"portraitLarge" => array( "name" => "portraitLarge", "width" => 1600, "height" => 2000, "crop" => false ),
				"postWide" => array( "name" => "postWide", "width" => 940, "height" => 383, "crop" => true ),
				"postExtraWide" => array( "name" => "postExtraWide", "width" => 1410, "height" => 575, "crop" => true ),
				"postFull" => array( "name" => "postFull", "width" => 940, "height" => 623, "crop" => true )
			);

			foreach ( $image_sizes as $key => $image_size ) {
				if ( !empty( $active_image_sizes[ $image_size['name'] ] ) && $active_image_sizes[ $image_size['name'] ] ) {
					add_image_size( $image_size['name'], $image_size['width'], $image_size['height'], $image_size['crop'] );
				}
			}
		}
	}

	/**
	 * Hides or shows the admin bar based on user role
	 */
	public static function intense_hide_admin_bar() {
		global $intense_visions_options;

		if ( is_user_logged_in() ) {
			$user = wp_get_current_user();
	        $roles = $intense_visions_options['intense_admin_bar_roles'];
	        $user_role = reset($user->roles);

	        if ( !empty( $roles ) && !empty( $user_role ) && is_array( $roles ) && array_key_exists( $user_role, $roles ) && empty( $roles[$user_role] ) ) {
	            show_admin_bar(false);
	        }
	    }
	}

	/**
	 * Establishes the redux URL as an absolute path to the Intense plugin URL
	 */
	public static function redux_url( $url ) {			
		return INTENSE_PLUGIN_URL . '/inc/plugins/ReduxFramework/ReduxCore/';
	}

	/**
	 * Adds missing mime types
	 *
	 * @param array   $existing_mimes list of mime types
	 */
	public static function add_mime_types( $existing_mimes ) {
		$existing_mimes['otf'] = 'font/opentype';
		$existing_mimes['eot'] = 'application/vnd.ms-fontobject';
		$existing_mimes['svg'] = 'image/svg+xml';
		$existing_mimes['ttf'] = 'application/octet-stream';
		$existing_mimes['woff'] = 'application/x-woff';

		// return the array back to the function with our added mime type
		return $existing_mimes;
	}

	/**
	 * Manually set the directory since load_plugin_textdomain doesn't like plugins as symlinks
	 *
	 * @param string  $mofile translation file
	 * @param string  $domain domain
	 * @return string         translation file
	 */
	public static function replace_default_language_files( $mofile, $domain ) {
		if ( 'intense' === $domain ) {
			return INTENSE_PLUGIN_FOLDER . '/languages/' . $domain . '-' . get_locale() . '.mo';
		}

		return $mofile;
	}
}

/**
 * Function that can be used to check if Intense is installed
 *
 * @return bool will always return true
 */
function intense_installed() {
	return true;
}

new Intense();
