<?php

if ( !class_exists( "Intense_Multisite_Options" ) ) {

	class Intense_Multisite_Options {
		public $args = array();
		public $sections = array();
		public $ReduxFramework;

		public function __construct( ) {
			// Set the default arguments
			$this->setArguments();

			// Set a few help tabs so you can see how it's done
			$this->setHelpTabs();

			// Create the sections and fields
			$this->setSections();

			if ( !isset( $this->args['opt_name'] ) ) { // No errors please
				return;
			}

			$intense_visions_options = get_option( 'intense_visions_options' );
			$options_are_set = !empty( $intense_visions_options );
			$intense_redux_option_set = isset( $intense_visions_options['intense_redux'] );

			if ( !$options_are_set || !$intense_redux_option_set || ( $intense_redux_option_set && $intense_visions_options['intense_redux'] )  ) {
				if ( !class_exists( 'ReduxFramework' ) && file_exists( INTENSE_PLUGIN_FOLDER . '/inc/plugins/ReduxFramework/ReduxCore/framework.php' ) ) {					
					require_once INTENSE_PLUGIN_FOLDER . '/inc/plugins/ReduxFramework/ReduxCore/framework.php';
				}
			}

			if ( !class_exists( "ReduxFramework" ) ) {
				return;
			}

			// If Redux is running as a plugin, this will remove the demo notice and links
			add_action( 'redux/plugin/hooks', array( $this, 'remove_demo' ) );

			// Dynamically add a section. Can be also used to modify sections/fields
			add_filter( 'redux/options/'.$this->args['opt_name'].'/sections', array( $this, 'dynamic_section' ) );

			// Add custom CSS for the options
			add_action( 'redux/page/'.$this->args['opt_name'].'/enqueue', array( $this, 'addPanelCSS' ) );

			// Add custom CSS for the options
			add_action( 'redux/options/'.$this->args['opt_name'].'/settings/change', array( $this, 'options_settings_change' ) );

			$this->ReduxFramework = new ReduxFramework( $this->sections, $this->args );
		}		

		public function addPanelCSS() {
			$minified = ( INTENSE_DEBUG ? "" : "min." );

			wp_register_style(
				'intense-redux-custom-css',
				INTENSE_PLUGIN_URL . '/assets/css/intense/options.' . $minified . 'css',
				array(), //array( 'redux-css' ), // Be sure to include redux-css so it's appended after the core css is applied
				time(),
				'all'
			);
			wp_enqueue_style( 'intense-redux-custom-css' );
		}

		public function options_settings_change() {
			flush_rewrite_rules(); //Resets the permalinks
		}

		public function setArguments() {
			$this->args = array(
				'dev_mode' => false,
				'dev_mode_icon_class' => 'icon-large',
				'opt_name' => 'intense_visions_multisite_options',
				'output_tag' => true,
				'display_name' => "Intense WordPress Plugin by Intense Visions",
				'display_version' => 'v' . INTENSE_PLUGIN_VERSION,
				'google_api_key' => 'AIzaSyBZYcKMU9hkCC9iBnDj3kdcX6c9E571vWw',
				'import_icon_class' => 'icon-large',
				'default_icon_class' => 'icon-large',
				'menu_type'  => 'submenu',
				'page_parent'        => 'options-general.php',
				'menu_title' => __( 'Intense Multisite', 'intense' ),
				'page_title' => __( 'Intense Multisite Options', 'intense' ),
				'page_slug' => 'intense_visions_multisite_options',
				'default_show' => false,
				'default_mark' => '*',
				'allow_sub_menu' => true,
				'menu_icon'=>'dashicons-intense-intense-logo',
				//'admin_bar' => true,
				'network_sites' => true,
				'network_admin' => false,
				'admin_bar'     => false,
				'database' => 'network',
				'page_permissions' => 'manage_network',
				'show_import_export' => false,
				//'transient_time' => '3600',
				'share_icons' => array(
					'twitter' => array(
						'link' => 'https://twitter.com/IntenseVisions',
						'title' => 'Follow Intense Visions on Twitter',
						'icon'  => 'el el-icon-twitter'
					),
					'facebook' => array(
						'link' => 'https://www.facebook.com/intensevision',
						'title' => 'Like Intense Visions on Facebook',
						'icon'  => 'el el-icon-facebook'
					),
					'google' => array(
						'link' => 'https://plus.google.com/b/100661863245884531948/100661863245884531948/',
						'title' => '+1 Intense Visions on Google+',
						'icon'  => 'el el-icon-googleplus'
					)
				),
			);
		}

		public function setHelpTabs() {

		}

		public function setSections() {
			require_once INTENSE_PLUGIN_FOLDER . '/inc/options/license.php';
		}

		function dynamic_section( $sections ) {			

			return $sections;
		}

		// Remove the demo link and the notice of integrated demo from the redux-framework plugin
		function remove_demo() {
			// Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
			if ( class_exists( 'ReduxFrameworkPlugin' ) ) {
				remove_filter( 'plugin_row_meta', array( ReduxFrameworkPlugin::get_instance(), 'plugin_meta_demo_mode_link' ), null, 2 );
			}

			// Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
			remove_action( 'admin_notices', array( ReduxFrameworkPlugin::get_instance(), 'admin_notices' ) );

		}
	}	
}
