<?php

class Intense_Code extends Intense_Shortcode {

	function __construct() {
        parent::__construct();

		global $intense_visions_options;

		$this->title = __( 'Code', 'intense' );
		$this->description = __( 'Use the code shortcode anytime you want to include code or preformatted text. The code can be shown in a block or inline. You can control the font color, background, and border radius (rounded corners).', 'intense' );
		$this->category = __( 'Typography', 'intense' );
		$this->show_preview = true;
		$this->preview_content = __( "Code", 'intense' );
		$this->vc_map_content = 'textarea';
	}

	function shortcode( $atts, $content = null ) {
		global $intense_visions_options;
		extract( shortcode_atts( $this->get_shortcode_defaults( null, $atts ), $atts ) );

		$radius = '';
		if ( isset( $border_radius ) ) {
			$radius = ' border-radius:' . $border_radius . ';';
		}

		$color = intense_get_plugin_color( $color );
        $font_color = intense_get_plugin_color( $font_color );

		if ( $font_color == '' ) {
			$font_color = intense_get_contract_color( $color );
		}

		$border_size = $intense_visions_options['intense_content_box_style']['border-top'];
		$border_color = $intense_visions_options['intense_content_box_style']['border-color'];
		$border_style = $intense_visions_options['intense_content_box_style']['border-style'];
		$border = 'border:' . $border_size . ' ' . $border_style . ' ' . $border_color . ';';

		$id = ( !empty ( $id ) ) ? ' id="' . $id . '"' : '';

		//fallback for old inline attribute
		if ( !empty( $inline ) ) {
			$type = 'inline';
		}

		switch ( $type ) {
			case 'css':
			case 'js':
			case 'html':
				$raw_content = rawurldecode( base64_decode( strip_tags( $raw_content ) ) );

				return $raw_content;
				break;
			case 'inline':
				$css = "background: " . $color  . "; padding: 5px; color: " . $font_color . "; $border $radius";
				break;
			default:
				$type = 'block';
				$css = "background: " . $color  . "; padding: 15px; $border $radius; color: $font_color;";
				break;
		}

        $extra_class =  ( !empty( $class ) ? ' ' . $class : '' );

        if ( isset( $atts['get_css'] ) && $atts['get_css'] ) {
            return array(
                'css' => $css,
                'base_classes' => 'intense code-' .$type,
                'extra_classes' => $extra_class
            );
        }

        switch ( $type ) {
			case 'inline':
				return "<code" . $id . " class='intense code-" . $type . $extra_class . "' style='" . $css . "'>" . trim( str_replace( "<br />", "", $content ) ) . "</code>";
				break;
			default:
				return "<pre" . $id . " class='intense code-" . $type . $extra_class . "' style='" . $css . "'><code style='color: " . $font_color . ";'>" . trim( str_replace( "<br />", "", $content ) ) . "</code></pre>";
				break;
		}
	}
}
