<?php

class Intense_Image extends Intense_Shortcode {

	function __construct() {
        parent::__construct();

		global $intense_visions_options;

		$this->title = __( 'Image', 'intense' );
		$this->description = __( 'Add responsive images to WordPress using the image shortcode. The image shortcode has several options for styling including shadows, border radius, multiple hover effects, and more.
			<br><br>
			Easily add a lightbox to the image. There are several different lightbox types to choose from.', 'intense' );
		$this->category = __( 'Media', 'intense' );
		$this->show_preview = true;
	}

	function shortcode( $atts, $content = null ) {
		global $intense_visions_options;
		extract( shortcode_atts( $this->get_shortcode_defaults( null, $atts ), $atts ) );
		
		$output = '';
		$imgID = '';
		$radius = '';
        $border_style = null;
        $border_top_style = null;
        $border_right_style = null;
        $border_bottom_style = null;
        $border_left_style = null;
        $box_shadow_style = null;
        $border_css = '';

        $lazy_load = isset( $lazy_load ) ? $lazy_load : isset( $intense_visions_options['intense_lazy_load'] ) ? $intense_visions_options['intense_lazy_load'] : true ;

        if ( $lazy_load ) {
        	intense_add_script( 'lazyloadxt' );
        	intense_add_script( 'intense.lazyload' );
        	intense_add_style( 'lazyloadxt.spinner' );
        	$image_src_attr = 'data-src';
        } else {
        	$image_src_attr = 'src';
        }

		if ( is_numeric( $image ) ) {
			$imageid = $image;
		} else if ( !empty( $image ) ) {
			$imageurl = $image;
		}
		
		switch ( $align ) {
			case '':				
				break;
			case 'left':
				$align = ' float:left';
				break;
			case 'right':
				$align = ' float:right';
				break;
			case 'middle':
				$align = ' vertical-align:middle';
				break;
			case 'top':
				$align = ' vertical-align:top';
				break;
			case 'bottom':
				$align = ' vertical-align:bottom';
				break;
		}		

		$width = null;
		$height = null;
		$w = null;
		$h = null;
		$shadow_style = '';
		$effeckt_style = '';
		$setItemprop = '';

		$alt = esc_attr( $alt );
		$split_title = explode(' ', $title, 3);
		$title = esc_attr( $title );
		$caption = esc_attr( $caption );

		if ( isset( $border_radius ) ) $radius = ' border-radius:' . $border_radius . ';';
        if ( isset( $border ) ) $border_style = "border: " . $border . ' !important;';
        if ( isset( $border_top ) ) $border_top_style = "border-top: " . $border_top . ' !important;';
        if ( isset( $border_right ) ) $border_right_style = "border-right: " . $border_right . ' !important;';
        if ( isset( $border_bottom ) ) $border_bottom_style = "border-bottom: " . $border_bottom . ' !important;';
        if ( isset( $border_left ) ) $border_left_style = "border-left: " . $border_left . ' !important;'; 
        if ( isset( $box_shadow ) ) $box_shadow_style = "box-shadow: " . $box_shadow . ';';

        $border_css = $border_style . $border_top_style . $border_right_style . $border_bottom_style . $border_left_style . $radius . $box_shadow_style;

        $wordpress_image_size = Intense_Photo_Source::get_wordpress_photo_sizes( $size );

		if ( $imageurl != '' && isset( $wordpress_image_size ) ) {
			$width = intval( $wordpress_image_size['width'] );
			$height = intval( $wordpress_image_size['height'] );
			$w = $width;
        	$h = $height;
		}

		if ( $effeckt != '' && isset( $effecktopacity ) && isset( $effecktcolor ) ) {
			$hex = str_replace( "#", "", $effecktcolor );
			$a = $effecktopacity / 100;

			if ( strlen( $hex ) == 3 ) {
				$r = hexdec( substr( $hex, 0, 1 ).substr( $hex, 0, 1 ) );
				$g = hexdec( substr( $hex, 1, 1 ).substr( $hex, 1, 1 ) );
				$b = hexdec( substr( $hex, 2, 1 ).substr( $hex, 2, 1 ) );
			} else {
				$r = hexdec( substr( $hex, 0, 2 ) );
				$g = hexdec( substr( $hex, 2, 2 ) );
				$b = hexdec( substr( $hex, 4, 2 ) );
			}

			$effeckt_style = "background: rgba(" . $r . "," . $g . "," . $b . "," . $a . ") !important; rgb(" . $r . "," . $g . "," . $b . ")\9 !important;";
		}

		if ( $imageid != '' ) {
			$photo = Intense_Photo_Source::get_wordpress_photo( $imageid, $size );
			$width = $photo['width'];
			$height = $photo['height'];
			$photo_url = $photo['url'];
			$w = $width;
			$h = $height;

			$full_size_photo = Intense_Photo_Source::get_wordpress_photo( $imageid, ( isset( $intense_visions_options['intense_photosource_full_size'] ) ? $intense_visions_options['intense_photosource_full_size'] : 'large' ) );
			$full_size_image = $full_size_photo['url'];
		} else {
			$photo_url = $imageurl;
		}

		if ( $itemprop != '' ) {
			$setItemprop = " itemprop='" . $itemprop . "'";
		}

		$subtleheight = '';
		if ( isset( $width ) ) { $width = " width='" . $width . "' "; }
		if ( isset( $height ) ) { $height = " height='" . $height . "' "; }
		if ( isset( $h ) ) { $subtleheight = $h - ( $h / 10 ); }

		//undo the width and height for imageurls because we don't know the size
		if ( !empty( $imageurl ) ) $width = $height = '';

		$imgID = ( !empty ( $id ) ) ? $id : 'img' . $imageid . '_' . rand();
		$shadow_style = "margin-bottom: 0; padding-bottom: 0; vertical-align: bottom !important;";
		$adipoliclass = "adipoli_" . rand();

		$effeckt_start = '';
		$effeckt_end = '';

		$additionalscript = '';

		if ( $effeckt != '' ) {
			intense_add_style( 'effeckt_caption' );

			$effeckt_start = "<figure class='intense effeckt-caption preload' data-effeckt-type='effeckt-caption-" . $effeckt . "'>";
			$effeckt_end = "<figcaption style='" . $effeckt_style . "'><div class='effeckt-figcaption-wrap'><h3>" . $title . "</h3><p>" . $caption . "</p></div></figcaption></figure><div class='clearfix'></div>";
			$additionalscript .= ' $(".preload").removeClass("preload"); ';
			$additionalscript .= ' if ($("#intense-browser-check").hasClass("ie8")) {
                $(".effeckt-caption").find("figcaption").fadeTo("fast", 0);
                $(".effeckt-caption").hover(
                    function() { $(this).find("figcaption").fadeTo("fast", ' . $effecktopacity / 100 . '); },
                    function() { $(this).find("figcaption").fadeTo("fast", 0); } );
            } ';
		}

		$shadow_start = '';
		$shadow_end = '';

		if ( $shadow ) {
			$shadow_start = "<div style='position: relative;'><div style='$shadow_style'>";
			$shadow_end = "</div><img src='" . INTENSE_PLUGIN_URL . "/assets/img/shadow{$shadow}.png' class='intense shadow' style='" . ( isset( $w ) ? 'width: ' . $w . 'px; height: auto;' : '' ) . "position: absolute; vertical-align: top; border:0px; border-radius: 0px; box-shadow: 0 0 0;' /></div>";
		}

		$link_start = '';
		$link_end = '';

		if ( $linkurl != '' ) {
			if ( !empty( $linkurl_rel ) ) $linkurl_rel = ' rel="' . $linkurl_rel . '"';

			$link_start = "<a" . $linkurl_rel . " href='" . $linkurl . "' target='" . $linkurl_target . "'>";
			$link_end = "</a>";
		}

		if ( !empty( $lightbox_type ) ) {
			require_once INTENSE_PLUGIN_FOLDER . '/inc/tools/lightboxes.php'; 
			
			$lightbox = Intense_Lightboxes::create( $lightbox_type, '#link_' . $imgID );
            $additionalscript .= $lightbox->get_image_script();
           	//add id to the link that is created so it can be found later. Also remove the ending link tag
            $link_start = str_replace("<a", '<a id="link_' . $imgID . '"', str_replace("</a>", '', $lightbox->get_image( $imgID, $title, $alt, ( isset( $full_size_image ) ? $full_size_image : $photo_url ), '' ) ) );
            $link_end = "</a>";
            $output .= '<style type="text/css">' . $lightbox->get_css() . '</style>';
		}

		// Add CSS/JS for different image types and add JavaScript setup code
		switch ( $type ) {
		case 'standard':
			$output .= $shadow_start;

			if ( isset( $hover_effect ) && $hover_effect == 'subtle' && isset( $subtleeffect ) ) {
				intense_load_subtle_effect_CSS( $subtleeffect );
				intense_add_script( 'intense.subtle.effect' );

				$output .= "<div class='intense subtle-effect'>";
				$output .= "<figure class='intense effect-" . $subtleeffect . "'>";
				$output .= "<img id='" . $imgID . "' class='subtle-effect-img' $width $height src='" . $photo_url . "' alt='" . $alt . "' class='" . ( !empty( $class ) ? $class : '' ) . "' title='" . $title . "' />";
				$output .= "<figcaption class='subtle-effect-caption'>";
				$output .= "<h2>" . ( !empty( $split_title[0] ) ? esc_html( $split_title[0] ) : '' ) . "<span>" . ( !empty( $split_title[1] ) ? ' ' . esc_html( $split_title[1] ) : '' ) . "</span>" . ( !empty( $split_title[2] ) ? ' ' . esc_html( $split_title[2] ) : '' ) . "</h2>";
				$output .= "<p>" . $caption . "</p>";

				if ( $linkurl != '' ) {
					$output .= "<a href='" . $linkurl . "' target='" . $linkurl_target . "'>View More</a>";
				}

				$output .= "</figcaption>";
				$output .= "</figure>";
				$output .= "</div>";
			} else {
				$output .= $link_start;
				$output .= $effeckt_start;
				$output .= "<img id='" . $imgID . "' $setItemprop $width $height style='" . $border_css . $align . "' " . $image_src_attr . "='" . $photo_url . "' alt='" . $alt . "' class='intense image" . ( !empty( $class ) ? ' ' . $class : '' ) . "' title='" . $title . "' />";
				$output .= $effeckt_end;
				$output .= $link_end;				
			}

			$output .= $shadow_end;

			break;
		case 'picstrip':
			// PicStrips jquery plugin
			intense_add_script( 'picstrips' );

			$additionalscript .= "    setTimeout(function(){ $('#$imgID').picstrips({ splits: $splits, hgutter: '$hgutter', vgutter: '$vgutter', bgcolor: '$bgcolor' }), 3000});";

			$output .= $effeckt_start;
			$output .= "<img style='width: 100%;' id='" . $imgID . "'" . $setItemprop . " " . "src='" . $photo_url . "' alt='" . $alt . "' title='" . $title . "' />";
			$output .= $effeckt_end;

			break;
		case 'caman':
			// CamanJS jquery plugin
			intense_add_script( 'camanjs' );

			$additionalscript .= "  setTimeout(function(){ Caman('#$imgID', function() {";
			$additionalscript .= "   this.$effect();";
			$additionalscript .= "   this.render();";
			$additionalscript .= "  }), 3000});";

			$output .= $shadow_start;
			$output .= $effeckt_start;
			$output .= "<img style='width: 100%;' id='" . $imgID . "' " . $image_src_attr . "='" . $photo_url . "' style='" . $border_css . $align . "' alt='" . $alt . "' title='" . $title . "' />";
			$output .= $effeckt_end;
			$output .= $shadow_end;

			break;
		case 'adipoli':
			intense_add_style( 'adipoli' );
			intense_add_script( 'adipoli' );

			if ( $starteffect != '' && $hovereffect != '' ) {
				$additionalscript .= "    var isOldIE = $('#intense-browser-check').hasClass('oldie'); ";
				$additionalscript .= "    if (!isOldIE) {";
				$additionalscript .= "      $('." . $adipoliclass . " img').adipoli({ 'startEffect': '" . $starteffect . "', 'hoverEffect': '" . $hovereffect . "' });";
				$additionalscript .="    }";
			}

			$output .= $shadow_start;
			$output .= $link_start;
			$output .= "<div class='" . $adipoliclass . "'><img id='" . $imgID . "' $width $height " . $image_src_attr . "='" . $photo_url . "' alt='" . $alt . "' class='" . ( !empty( $class ) ? $class : '' ) . "' title='" . $title . "' /></div>";
			$output .= $link_end;
			$output .= $shadow_end;

			break;
		case 'parallax':
			$output .= $shadow_start;
			$output .= $effeckt_start;
			$output .= intense_run_shortcode( 'intense_content_section', array( 
				'height' => $parallax_height,
				'size' => 'full',
				'breakout' => '0',
				'speed' => $parallax_speed,
				'imageurl' => $photo_url,
				'border_bottom' => '0',
				'border_top' => '0',
				'imagemode' => 'parallax',
				'margin_top' => '0',
				'margin_bottom' => '0'
			) );			
			$output .= $effeckt_end;
			$output .= $shadow_end;

			break;
		case 'fixed':
			$output .= $shadow_start;
			$output .= $effeckt_start;
			$output .= intense_run_shortcode( 'intense_content_section', array( 
				'height' => $parallax_height,
				'size' => 'full',
				'breakout' => '0',
				'speed' => $parallax_speed,
				'imageurl' => $photo_url,
				'border_bottom' => '0',
				'border_top' => '0',
				'imagemode' => 'fixed',
				'margin_top' => '0',
				'margin_bottom' => '0'
			) );			
			$output .= $effeckt_end;
			$output .= $shadow_end;

			break;
		}

		if ( isset( $additionalscript ) && $additionalscript != '' ) {
			$output .= "<script> jQuery(function($) {";
			$output .= " $(document).ready(function() {";
			$output .= $additionalscript;
			$output .= " });";
			$output .= "});</script>";
		}

		return $output;
	}
}
