<?php

class Intense_Recent_Posts extends Intense_Shortcode {

	function __construct() {
        parent::__construct();

		global $intense_visions_options;

		$this->title = __( 'Recent Posts', 'intense' );
		$this->description = __( 'The recent posts shortcode lets you include your recent posts using three different layouts. Place your recent WordPress posts on a page using any of these layouts:
			<ul>
			<li><strong>horizontal</strong> – posts are side by side</li>
			<li><strong>vertical</strong> – posts are one on top of another</li>
			<li><strong>slider</strong> – posts are in a horizontal slider</li>
			</ul>

			Each layout comes with predefined templates. Templates allow you to customize the look to suit your needs.
			<br><br>
			There are many different options to filter the posts that are shown. Show posts with specific categories, tags, or formats. Choose how to order the posts and how many to show. You can also exclude specific posts or categories.', 'intense' );
		$this->category = __( 'Posts', 'intense' );		
		$this->show_preview = true;
		$this->map_visual_composer = false;
	}

	function shortcode( $atts, $content = null ) {
		global $intense_visions_options, $intense_recent_post, $intense_post_types;
		extract( shortcode_atts( $this->get_shortcode_defaults( null, $atts ), $atts ) );

		global $wp_query;

		$intense_post_type = $intense_post_types->get_post_type( $post_type );

		$intense_recent_post = array(
            'post_type' => $intense_post_type       
		);

		$intense_recent_post = array_merge( $this->get_shortcode_defaults( null, $atts ), $atts, $intense_recent_post );

		$i = 1;
	    $column_width = floor( 12 / $columns );

	    $args = array(
	        'paged' => true,
	        'posts_per_page' => $post_count,
	    );

	    if ( !isset( $post_type ) && ( isset( $not_post_id ) ||  ( isset( $related_post_id ) && $related_post_id != '' ) ) ) {
	        $post_type = get_post_type( isset( $related_post_id ) ? $related_post_id : $not_post_id );
	    }

	    if ( isset( $post_type ) ) {
	        $args["post_type"] = $post_type;
	    }

	    $radius = '';
	    if ( isset( $border_radius ) ) {
			if ( is_numeric( $border_radius ) ) {
				$border_radius .= 'px';
			}

	        $radius = ' border-radius:' . $border_radius . ';';
	    }

	    if ( isset( $related_post_id ) && $related_post_id != '' ) {
	        $tags = wp_get_post_terms( $related_post_id, $taxonomy );
	        $first_tag = 'bananabananabanana';
	        $second_tag = 'bananabananabanana';
	        $third_tag = 'bananabananabanana';
	        $category_id = '';

	        // first try by taxonomy
	        // fallback to category
	        if ( isset( $tags ) && count( $tags ) > 0 ) {
	            if ( isset( $tags[0] ) ) $first_tag  = $tags[0]->term_id;
	            if ( isset( $tags[1] ) ) $second_tag = $tags[1]->term_id;
	            if ( isset( $tags[2] ) ) $third_tag  = $tags[2]->term_id;

	            $args['tax_query'] = array(
	                'relation' => 'OR',
	                array(
	                    'taxonomy' => $taxonomy,
	                    'terms' => $second_tag,
	                    'field' => 'id',
	                    'operator' => 'IN',
	                ),
	                array(
	                    'taxonomy' => $taxonomy,
	                    'terms' => $first_tag,
	                    'field' => 'id',
	                    'operator' => 'IN',
	                ),
	                array(
	                    'taxonomy' => $taxonomy,
	                    'terms' => $third_tag,
	                    'field' => 'id',
	                    'operator' => 'IN',
	                )
	            );
	        } else {
	            $categories = get_the_category();
	            if ( isset( $categories[0] ) ) {
	                $category_id = $categories[0]->cat_ID;
	            }
	        }
	    }

	    if ( ( isset( $category_id ) && $category_id != '' ) || ( isset( $category_slug ) && $category_slug != '' ) ) {
	        if ( isset( $post_type ) && $post_type != "post" ) {
	        	if ( isset( $category_id ) && $category_id != '' ) {
	        		if ( strpos( $category_id, ',' ) ) {
						$category_id = explode( ',', str_replace( ' ', '', $category_id ) );
						$args['tax_query'] = array(
							array(
								'taxonomy' => $taxonomy,
								'field'  => 'term_id',
								'terms'  => $category_id
							)
						);
	        		} else {
						$args['tax_query'] = array(
							array(
								'taxonomy' => $taxonomy,
								'field'  => 'term_id',
								'terms'  => array( $category_id )
							)
						);
	        		}
	        	} else {
	        		if ( strpos( $category_slug, ',' ) ) {
						$category_slug = explode( ',', str_replace( ' ', '', $category_slug ) );
						$args['tax_query'] = array(
							array(
								'taxonomy' => $taxonomy,
								'field'  => 'slug',
								'terms'  => $category_slug
							)
						);
	        		} else {
						$args['tax_query'] = array(
							array(
								'taxonomy' => $taxonomy,
								'field'  => 'slug',
								'terms'  => array( $category_slug )
							)
						);
	        		}
	        	}
	        } else {
	        	if ( isset( $category_id ) && $category_id != '' ) {
	        		if ( strpos( $category_id, ',' ) ) {
		        		$category_id = explode( ',', $category_id );
		            	$args['category__in'] = $category_id;

	        		} else {
		            	$args['category__in'] = array( $category_id );
		            }
	        	} else {
	        		$args['category_name'] = $category_slug;
	        	}
	        }
	    } else if ( isset( $categories ) && $categories != '' ) {	    	
			if ( is_array( $categories ) ) {
				$categories = $categories;
			} else if ( strpos( $categories, ',' ) ) {				
				$categories = explode( ',', str_replace( ' ', '', $categories ) );				
			} else {
				$categories = array( $categories );				
			}

			$args['tax_query'] = array(
				array(
					'taxonomy' => $taxonomy,
					'field'  => 'slug',
					'terms'  => $categories
				)
			);
	    } else {
	    	if ( $taxonomy != '' ) {
		    	$categories = get_terms( $taxonomy, array( 'fields' => 'ids' ) );

		    	if ( isset( $post_type ) && $post_type != "post" ) {
		            $args['tax_query'] = array(
		                array(
		                    'taxonomy' => $taxonomy,
		                    'field' => 'term_id',
		                    'terms' => $categories
		                )
		            );
		    	} else {
					$args['category__in'] = $categories;
		    	}
		    }
	    }
	    if ( isset( $not_post_id ) && $not_post_id != '' ) {
	        $args['post__not_in'] = explode(',', $not_post_id );
	    }

	    $post_query = new WP_Query( $args );

	    $output = "";

	    if ( !$post_query->have_posts() ) {
	        $output .= $no_post_message;
	    }

	    $horizontal = "";
	    $horizontal_ended = false;

	    $slider = '';

	    while ( $post_query->have_posts() ): $post_query->the_post();
	        global $post;

	        $intense_recent_post['template_link_url'] = $intense_post_type->get_link( $template_link );

	        if ( $layout == "vertical" ) {
	        	$template_content = intense_get_template( array(
					'/recent-post/' .  get_post_type() . '/' . $template . '.php',
					'/recent-post/post/' . $template . '.php',
					'/recent-post/post/top.php'
				) );
		        $output .= do_shortcode( $template_content );
		    } else if ( $layout == 'slider' ) {
		    	if ( $i == 1 ) {
		    		$slider .= '[intense_slider type="owl-carousel" 
		    			items="' . $items . '"
                    	items_desktop="' . $items_desktop . '"
                    	items_desktop_small="' . $items_desktop_small . '"
                    	items_tablet="' . $items_tablet . '"
                    	items_mobile="' . $items_mobile . '"
                    	navigation_position="' . $navigation_position . '"
                    	navigation_prev_icon_source="' . $navigation_prev_icon_source . '"
                    	navigation_prev_icon="' . $navigation_prev_icon . '"
                    	navigation_next_icon_source="' . $navigation_next_icon_source . '"
                    	navigation_next_icon="' . $navigation_next_icon . '"
                    	navigation_size="' . $navigation_size . '"
                    	navigation_prev_text="' . $navigation_prev_text . '"
                    	navigation_next_text="' . $navigation_next_text . '"
                    	navigation_color="' . $navigation_color . '"
                    	navigation_font_color="' . $navigation_font_color . '"
                    	navigation_prev_border_radius="' . $navigation_prev_border_radius . '"
                    	navigation_next_border_radius="' . $navigation_next_border_radius . '"
                    	navigation_pagination_type="' . $navigation_pagination_type . '"
                    	mousedrag="' . $mousedrag . '"
                    	touchdrag="' . $touchdrag . '"
						autoheight="' . $autoheight . '"
		    		]';
		    	}

		    	$template_content = intense_get_template( array(
					'/recent-post/' .  get_post_type() . '/' . $template . '.php',
					'/recent-post/post/' . $template . '.php',
					'/recent-post/post/top.php'
				) );

		    	$slider .= '[intense_slide]<div style="padding: 0 ' . $slide_padding_right . 'px 0 0">' . do_shortcode( $template_content ) . '</div>[/intense_slide]';
	        } else {
		       $horizontal_ended = false;

	            if ( $i == 1 ) {
	                if ( $horizontal == "" ) {
	                    $horizontal .= "[intense_row padding_top='0']";
	                } else {
	                    $horizontal .= "[intense_row padding_top='30']";
	                }
	            }

	            $horizontal .= "[intense_column size='$column_width']";
	            $template_content = intense_get_template( array(
					'/recent-post/' .  get_post_type() . '/' . $template . '.php',
					'/recent-post/post/' . $template . '.php',
					'/recent-post/post/top.php'
				) );
		        $horizontal .= do_shortcode( $template_content );
	            $horizontal .= "[/intense_column]";

	            if ( $i == $columns ) {
	                $horizontal .= "[/intense_row]";
	                $i = 0; //leave at 0 since it will get incremented later to 1                
			        $horizontal_ended = true;
	            }
	        }

			$i++;
	    endwhile;

	    if ( $post_query->have_posts() && $layout == "horizontal" ) {
	        if ( !$horizontal_ended ) {
	            $horizontal .= "[/intense_row]";
	            $i = 0;
	        }

		   $output .= do_shortcode( $horizontal );
	    }

	    if ( !empty( $slider ) ) {
	    	$slider .= '[/intense_slider]';
	    	$output .= do_shortcode( $slider );
	    }
	    
	    return $output;
	}	
}

