<?php

class Intense_Tabs extends Intense_Shortcode {

	function __construct() {
        parent::__construct();

		global $intense_visions_options;

		$this->title = __( 'Tabs', 'intense' );
		$this->description = __( 'Quickly add tabs to WordPress using the tab shortcode. Change the tab color, border color, and positions. Add icons to the tab titles. You can also have a tab link to another page. Tabs allow you to easily organize content into a small area. There are several different animations that add an extra effect.', 'intense' );
		$this->category = __( 'Layout', 'intense' );
		$this->show_preview = false;
		$this->is_container = true;
	}

	function shortcode( $atts, $content = null ) {
		global $intense_visions_options;
		extract( shortcode_atts( $this->get_shortcode_defaults( null, $atts ), $atts ) );

		$output = "";

		if ( isset( $direction ) ) {
			$direction = "tabs-" . $direction;
		}

		$GLOBALS['IntensePluginInlineStyle']['Intense Tab'] = "
	        	.intense.nav-tabs>.active>a, .intense.nav-tabs>.active>a:hover, .intense.nav-tabs>.active>a:focus {
	        		background-color: " . intense_get_plugin_color( "boxed" ) . ";
	        	}

	        	.intense.nav-tabs>li>a {
		            background-color: " . intense_adjust_color_brightness( intense_get_plugin_color( "boxed" ), 15 ) . ";
		        }

		        .intense.nav-tabs>.active>a, .intense.nav-tabs>.active>a:hover, .intense.nav-tabs>.active>a:focus{
		        	color: " . intense_get_plugin_color( "primary" ) . ";
		        }
	        ";

		intense_add_script( 'intense.tabs' );

		//old technique using intense_tab_list, intense_tab, intense_tab_contents, and intense_tab_pane shortcodes
		if ( stripos( $content, 'intense_tab_list' ) !== false ) {			
			$content = str_replace( 'intense_tab ', 'intense_tab_original ', $content );
			$content = str_replace( 'intense_tab]', 'intense_tab_original]', $content );
			$content = str_replace( 'intense_tab_contents', 'intense_tab_original_contents', $content );
			$content = str_replace( 'intense_tab_pane', 'intense_tab_original_pane', $content );
			$content = str_replace( 'intense_tab_list', 'intense_tab_original_list', $content );

			$output .= '<div class="intense tabbable preload effeckt-tabs-wrap ' . $direction . '" data-effeckt-type="' . $animation . '">';
			$output .= do_shortcode( $content );
			$output .= '</div>';
		} else {
			global $intense_tab_array;

			$intense_tab_array = array();

			//setup id for ul so colors can be set for active tab
			$tab_id = 'tab_' . rand();

			$style = '';

			if ( empty( $id ) ) $id = rand();

			//gather array of tabs
			do_shortcode( $content );

			$tab_list = '<style>';

			if ( !empty( $active_tab_background_color ) ) {
				$tab_list .= '#' . $tab_id . '.intense.nav-tabs>li.active a { background-color: ' . $active_tab_background_color . ' !important; }';
			}

			if ( !empty( $active_tab_font_color ) ) {
				$tab_list .= '#' . $tab_id . '.intense.nav-tabs>li.active h4, #' . $tab_id . '.intense.nav-tabs>li.active i { color: ' . $active_tab_font_color . ' !important; }';
			}
			
			$tab_list .= '</style>';
			
			$tab_list .= '<ul id="' . $tab_id . '" class="intense nav nav-tabs effeckt-tabs ' . ( is_rtl() ? 'rtl ' : '' ) . '" >';

		 	foreach ( $intense_tab_array as $key => $value ) {
		 		$value['trigger'] = $trigger;
		 		$value['direction'] = $direction;
				$tab_list .= $this->render_tab( $id . '_' . $key, $value );
		 	}

	 		$tab_list .= '</ul>';

			if ( !empty( $width ) ) {
				if ( is_numeric( $width ) ) $width .= 'px';

				$style .= ' width: ' . $width . ';';
			} else {
				$style .= ' width: 100%;';
			}

			$data_attributes = '';

			if ( !empty( $autoplay ) ) {
				$data_attributes .= ' data-autoplay="' . $autoplay . '"';
			}

			if ( !empty( $speed ) ) {
				$data_attributes .= ' data-speed="' . $speed . '"';
			}

			if ( !empty( $delay ) ) {
				$data_attributes .= ' data-delay="' . $delay . '"';	
			}

			if ( isset( $reset ) ) {
				$data_attributes .= ' data-reset="' . $reset . '"';	
			} else {
				$data_attributes .= ' data-reset="1"';	
			}

			if ( isset( $loop ) ) {
				$data_attributes .= ' data-loop="' . $loop . '"';	
			} else {
				$data_attributes .= ' data-loop="1"';	
			}

		 	$output .= '<div class="intense tabbable preload effeckt-tabs-wrap ' . $direction . ( !empty( $class ) ? ' ' . $class : '' ) . '"' . $data_attributes . ' data-effeckt-type="' . $animation . '"' . ( !empty( $style ) ? ' style="' . $style . '"' : '' ) . '>';

		 	if ( $direction != 'tabs-below' ) {
		 		$output .= $tab_list;
		 	}

	 		$output .= '<div class="intense tab-content effeckt-tabs-container" style="background-color: transparent;">';
			
			foreach ( $intense_tab_array as $key => $value ) {
				$output .= $this->render_tab_pane( $id . '_' . $key, $value );
		 	}

			$output .= '</div>';

			if ( $direction == 'tabs-below' ) {
		 		$output .= $tab_list;
		 	}

			$output .= '</div>';
		}

		return $output;
	}

	function render_tab( $id, $tab ) {
		extract( shortcode_atts( array(				
				"title" => "Tab",
				"active" => 0,
				"link" => null,
				'link_target' => '',
				'link_rel' => '',
				"background_color" => null,
				"font_color" => null,
				"border_color" => null,
				"border" => '3px solid ' . intense_get_plugin_color('boxed'),
				"icon_position" => "left",
				"icon_source" => "font-awesome",
				"icon_type"  => null,
				"icon_size"  => '1',
				"icon_spin"  => 0,
				"icon_color" => '',
				"icon_rotate" => null,
				"icon_flip" =>  null,
				"icon_stack_source" => "font-awesome",
				"icon_stack_type" => null,
				"icon_stack_color" => null,
				'custom_icon' => null,
				'content_background_color' => 'boxed',
				'content_font_color' => null,
				'content' => null,
				'trigger' => 'click',
				'direction' => null
			), $tab ) );

		$icon = "";
		$data_trigger = ' data-trigger="' . ( empty( $trigger ) ? 'click' : $trigger ) . '"';
		$link_class = '';
		$border_css = '';

		if ( isset( $icon_type ) ) {
			$icon = intense_run_shortcode( 'intense_icon', array(
				'source' => $icon_source,
				'type' => $icon_type,
				'color' => $icon_color,
				'size' => $icon_size,
				'spin' => $icon_spin,
				'rotate' => $icon_rotate,
				'flip' => $icon_flip,
				'stack_source' => $icon_stack_source,
				'stack_type' => $icon_stack_type,
				'stack_color' => $icon_stack_color
			));			
		}

		if ( isset( $custom_icon ) ) {
			if ( is_numeric( $custom_icon ) ) {
				$photo = Intense_Photo_Source::get_wordpress_photo( $custom_icon, null );
		    	$custom_icon = $photo['url'];
		    }
		    
			$icon = '<img class="intense img-icon' . ( $icon_size - 1 ) . 'x" src="' . $custom_icon . '" alt="" />';
		}

		if ( !isset( $link ) ) {
			$link = "#" . $id;
			$link_class = "effeckt-tab";
		}

		if ( is_numeric( $link ) ) {
			$link = get_permalink( $link );
		}

		if ( !empty( $border ) ) {
			$border_css_parts = intense_get_border_array( $border );

			switch ($direction) {
				case 'tabs-below':
					$border_direction = 'bottom';
					break;
				case 'tabs-left':
					$border_direction = 'left';
					break;
				case 'tabs-right':
					$border_direction = 'right';
					break;
				default:
					$border_direction = 'top';
					# code...
					break;
			}
			$border_css = ' border-color:' . $border_css_parts['color'] . ';';
			$border_css .= ' border-style:' . $border_css_parts['style'] . ';';
			$border_css .= ' border-' . $border_direction . '-width:' . $border_css_parts['width'] . ' !important;';
		}

		if ( !empty( $border_color ) ) {					
			$border_color = intense_get_plugin_color( $border_color );
			$border_css .= " border-color: " . $border_color . ";";
		}		

		$background_color = intense_get_plugin_color( $background_color );

		if ( isset( $background_color ) ) {
			$background_color = " background-color: " . $background_color . ";";
		}

		$font_color = intense_get_plugin_color( $font_color );

		if ( isset( $font_color ) ) {
			$font_color = " color: " . $font_color . ";";
		}

		if ( !empty( $link_rel ) ) $link_rel = ' rel="' . $link_rel . '"';

		return '<li class="' . ( $active ? "active" : "" ) . '"><a' . $link_rel . ' href="' . $link . '" class="' . $link_class . '" target="' . $link_target . '" ' . $data_trigger . ' style="' . $border_css . $background_color . '"><h4 style="' . $font_color . '">' . ( $icon_position == "left" ? $icon . " " : "" ) . $title . ( $icon_position == "right" ? " " . $icon : "" ) . '</h4></a></li>';
	}

	function render_tab_pane( $id, $tab ) {
		extract( shortcode_atts( array(				
				"title" => "Tab",
				"active" => 0,
				"link" => null,
				'link_target' => '',
				'link_rel' => '',
				"background_color" => null,
				"font_color" => null,
				"border_color" => null,
				"border" => '3px solid ' . intense_get_plugin_color('boxed'),
				"icon_position" => "left",
				"icon_source"  => "font-awesome",
				"icon_type"  => null,
				"icon_size"  => '1',
				"icon_spin"  => 0,
				"icon_color" => '',
				"icon_rotate" => null,
				"icon_flip" =>  null,
				"icon_stack_source" => "font-awesome",
				"icon_stack_type" => null,
				"icon_stack_color" => null,
				'custom_icon' => null,
				'content_background_color' => 'boxed',
				'content_font_color' => null,
				'content' => null				
			), $tab ) );

		$content_background_color = intense_get_plugin_color( $content_background_color );

		if ( isset( $content_background_color ) ) {
			$content_background_color = " background-color: " . $content_background_color . " !important;";
		}

		$content_font_color = intense_get_plugin_color( $content_font_color );

		if ( isset( $content_font_color ) ) {
			$content_font_color = " color: " . $content_font_color . " !important;";
		}

		return '<div class="intense tab-pane effeckt-tab-content ' . ( $active ? "active effeckt-show" : "" ) . '" id="' . $id . '" style="visibility: hidden;' . $content_font_color . $content_background_color . '">' . do_shortcode( $content ) . "</div>";
	}	
}

add_shortcode( 'intense_tab_original_list', 'intense_tab_list_shortcode' );
add_shortcode( 'intense_tab_original', 'intense_tab_original_shortcode' );
add_shortcode( 'intense_tab_original_contents', 'intense_tab_contents_shortcode' );
add_shortcode( 'intense_tab_original_pane', 'intense_tab_pane_shortcode' );

function intense_tab_list_shortcode( $atts, $content = null ) {
	global $intense_visions_options;

	//setup id for ul so colors can be set for active tab
	$id = 'tab_' . rand();

	extract( shortcode_atts( array(), $atts ) );

	$output = '<ul class="intense nav nav-tabs effeckt-tabs ' . ( is_rtl() ? 'rtl ' : '' ) . '" >';
	$output .= do_shortcode( $content );
	$output .= '</ul>';

	return $output;
}

function intense_tab_original_shortcode( $atts, $content = null ) {
	extract( shortcode_atts( array(
				"id" => "tab1",
				"active" => 0,
				"link" => null,
				'link_target' => '',
				'link_rel' => '',
				"background_color" => null,
				"font_color" => null,
				"border_color" => "boxed",
				"icon_position" => "left",
				"icon_source"  => "font-awesome",
				"icon_type"  => null,
				"icon_size"  => '1',
				"icon_spin"  => 0,
				"icon_color" => '',
				"icon_rotate" => null,
				"icon_flip" =>  null,
				"icon_stack_source" => "font-awesome",
				"icon_stack_type" => null,
				"icon_stack_color" => null,
				'custom_icon' => null
			), $atts ) );

	$icon = "";
	$data_toggle = "";
	$link_class = '';

	if ( isset( $icon_type ) ) {
		$icon = intense_run_shortcode( 'intense_icon', array(
				'source' => $icon_source,
				'type' => $icon_type,
				'color' => $icon_color,
				'size' => $icon_size,
				'spin' => $icon_spin,
				'rotate' => $icon_rotate,
				'flip' => $icon_flip,
				'stack_source' => $icon_stack_source,
				'stack_type' => $icon_stack_type,
				'stack_color' => $icon_stack_color,
				'custom_icon' => $custom_icon
			));
	}

	if ( !isset( $link ) ) {
		$link = "#" . $id;
		//$data_toggle = 'data-toggle="tab"';
		$link_class = "effeckt-tab";
	}

	$border_color = intense_get_plugin_color( $border_color );
	
	if ( !empty( $border_color ) ) {
			$border_color = " border-color: " . $border_color . ";";
	}
	
	$background_color = intense_get_plugin_color( $background_color );

	if ( isset( $background_color ) ) {
		$background_color = " background-color: " . $background_color . " !important;";
	}

	$font_color = intense_get_plugin_color( $font_color );

	if ( isset( $font_color ) ) {
		$font_color = " color: " . $font_color . " !important;";
	}

	return '<li class="' . ( $active ? "active" : "" ) . '"><a href="' . $link . '" class="' . $link_class . '" target="' . $link_target . '" ' . $data_toggle . ' style="' . $border_color . $background_color . '"><h4 style="' . $font_color . '">' . ( $icon_position == "left" ? $icon . " " : "" ) . do_shortcode( $content ) . ( $icon_position == "right" ? " " . $icon : "" ) . '</h4></a></li>';
}

function intense_tab_contents_shortcode( $atts, $content = null ) {

	$output = '<div class="intense tab-content effeckt-tabs-container" style="background-color: transparent;">';
	$output .= do_shortcode( $content );
	$output .= '</div>';

	return $output;
}

function intense_tab_pane_shortcode( $atts, $content = null ) {
	extract( shortcode_atts( array(
				"id" => "tab1",
				"active" => 0,
				"background_color" =>  intense_get_plugin_color( "boxed" ),
				"font_color" => null
			), $atts ) );

	$background_color = intense_get_plugin_color( $background_color );

	if ( isset( $background_color ) ) {
		$background_color = " background-color: " . $background_color . " !important;";
	}

	$font_color = intense_get_plugin_color( $font_color );

	if ( isset( $font_color ) ) {
		$font_color = " color: " . $font_color . " !important;";
	}

	return '<div class="intense tab-pane effeckt-tab-content ' . ( $active ? "active effeckt-show" : "" ) . '" id="' . $id . '" style="visibility: hidden;' . $font_color . $background_color . '">' . do_shortcode( $content ) . "</div>";
}
