<?php

class Intense_Testimonies extends Intense_Shortcode {

	function __construct() {
        parent::__construct();

		global $intense_visions_options;

		$this->title = __( 'Testimonies', 'intense' );
		$this->description = __( 'Add testimonies to your WordPress posts and pages using the testimonies shortcode. Testimonies can be manually added or pulled from the Intense testimonials posts. Testimonies layouts are created using templates. Testimonies can be shown in a slider.', 'intense' );
		$this->category = __( 'Layout', 'intense' );
		$this->show_preview = true;
		$this->is_container = true;
	}

	function shortcode( $atts, $content = null ) {
		global $intense_visions_options;
		extract( shortcode_atts( $this->get_shortcode_defaults( null, $atts ), $atts ) );

		$output = '';

		$id = ( !empty ( $id ) ) ? ' id="' . $id . '"' : '';

		if ( $type == 'slider' ) {
			intense_add_script( 'intense.basicslider' );

			$slider = "data-basicslider='true'";
			$slider_script = "<script> jQuery(function($){";
			$slider_script .= " $(document).ready(function() {";
			$slider_script .= "    $('[data-basicslider=\"true\"]').basicslider({
                            speed: " . $speed . ",
                            pauseOnHover: " . ( $pause_on_hover ? 'true' : 'false' ) . "
                        });";
			$slider_script .= "	});";
			$slider_script .= "}); </script>";
			$extra_class = "testimonies-slider";
		} else {
			$slider = null;
			$slider_script = "";
			$extra_class = null;
		}		

        if ( !empty( $template ) ) {
	        global $intense_testimonies;
	        global $intense_testimony;

			$intense_testimonies = array();

			if ( $source == 'manual' ) {
				//gather array of testimonies
				do_shortcode( $content );
			} else {
				//get testimonies from custom post type

				global $post, $wp_query;

				$args = array(
					'post_type' => 'intense_testimonials',
					'orderby' => $order_by,
					'order' => $order,
					'nopaging'=> true,
					'tax_query' => ''
				);

				$post_query = new WP_Query( $args );

				while ( $post_query->have_posts() ) {
					$post_query->the_post();

					$link = get_field( 'intense_testimonial_link' );

					if ( is_numeric ( $link ) ) {
						$link = get_permalink( $link );
					}
					
					$intense_testimonies[] = array(
						'author' => get_field( 'intense_testimonial_author' ),
						'company' => get_field( 'intense_testimonial_company' ),
						'link' => $link,
						'link_target' => get_field( 'intense_testimonial_link_target' ),
						'image' => get_field( 'intense_testimonial_author_image' ),
						'background' => get_field( 'intense_testimonial_background' ),
						'font_color' => get_field( 'intense_testimonial_font_color' ),
						'content' => intense_content( 50 ),
					);
				}
			}		

			$output .= "<div " . $id . " class='intense testimonies $extra_class " . ( !empty( $class ) ? ' ' . $class : '' ) . " " . ( is_rtl() ? 'rtl ' : '' ) . "' $slider>";

			foreach ($intense_testimonies as $key => $testimony) {
				if ( !empty( $testimony['background'] ) && in_array( $testimony['background'], array( "warning", "error", "success", "info", "inverse", "muted", "primary" ) ) ) {
		            $testimony['background'] = intense_get_plugin_color( $testimony['background'] );
		        }

		        if ( !empty( $testimony['font_color'] ) && in_array( $testimony['font_color'], array( "warning", "error", "success", "info", "inverse", "muted", "primary" ) ) ) {
		            $testimony['font_color'] = intense_get_plugin_color( $testimony['font_color'] );
		        }

				$intense_testimony = $testimony;

				$output .= intense_get_template( array(
					'/testimonies/' . $template . '.php',
					'/testimonies/original.php'
				) );
			}

			$output .= "</div>$slider_script";

			return $output;
		} else {
			//old method
			
			$testimony_style = "
	        <style type='text/css'>
	        	.testimony > .content {
	        		background-color: " . intense_get_plugin_color( "boxed" ) . " !important;
	        	}
	            .testimony > .content:after {
	           		border-right-color: " . intense_get_plugin_color( "boxed" ) . " !important;
	        	}
	        </style>";

			
			return $testimony_style . "<div class='intense testimonies $extra_class " . ( is_rtl() ? 'rtl ' : '' ) . "' $slider>" . do_shortcode( $content ) . "</div>$slider_script";
		}
	}	
}

// deprecated shortcodes
add_shortcode( 'intense_testimony_author', 'intense_testimony_author_shortcode' );
add_shortcode( 'intense_testimony_text', 'intense_testimony_text_shortcode' );

function intense_testimony_text_shortcode( $atts, $content = null ) {
	return "<div class='content'>" . do_shortcode( $content ) . "</div>";
}

function intense_testimony_author_shortcode( $atts, $content = null ) {
	global $intense_visions_options;
	
	extract( shortcode_atts( array(
				"company" => '',
				"link" => '',
				'link_target' => '',
				'link_rel' => '',
				"image" => '',
			), $atts ) );

	if ( strlen( $image ) > 0 ) {
		if ( is_numeric( $image ) ) {
			//THIS DOESN'T PULL IMAGES LIKE EVERYTHING ELSE DOES, REWRITE IF CHANGED
			$image_url = wp_get_attachment_image_src( $image ); // returns an array			
			$image = '<img src="' . $image_url[0] . '" alt="' . esc_attr( $company ) . '" />';
		} else {
			$image = '<img src="' . $image . '" alt="' . esc_attr( $company ) . '" />';
		}
	} else {
		$image = intense_run_shortcode( 'intense_icon', array( 'source' => $intense_visions_options['intense_user_icon']['source'], 'type' => $intense_visions_options['intense_user_icon']['type'], 'size' => '2' ) );
	}

	if ( !empty( $link_rel ) ) $link_rel = ' rel="' . $link_rel . '"';

	return "<div class='author'>$image " . do_shortcode( $content ) . ( strlen( $company ) > 0 ? "<span class='company'>, " . ( strlen( $link ) ? "<a" . $link_rel . " href='$link' target='$link_target'>" : "" ) . $company . ( strlen( $link ) ? "</a></span>" : "</span>" ) : "" )  . "</div>";
}
